@@ -13,8 +13,6 @@ from pathlib import Path
 from shutil import rmtree as rmdir
 from datetime import datetime
 from fosslight_binary import binary_analysis
-from fosslight_source.cli import run_all_scanners as source_analysis
-from fosslight_source.cli import create_report_file
 from fosslight_dependency.run_dependency_scanner import run_dependency_scanner
 from fosslight_util.download import cli_download_and_extract
 from ._get_input import get_input_mode
@@ -26,6 +24,13 @@ from fosslight_reuse._fosslight_reuse import run_lint as reuse_lint
 from .common import (copy_file, call_analysis_api,
                      overwrite_excel, extract_name_from_link)
 from fosslight_util.write_excel import merge_excels
+import subprocess
+fosslight_source_installed = True
+try:
+    from fosslight_source.cli import run_all_scanners as source_analysis
+    from fosslight_source.cli import create_report_file
+except ModuleNotFoundError:
+    fosslight_source_installed = False
 
 OUTPUT_EXCEL_PREFIX = "FOSSLight-Report_"
 OUTPUT_JSON_PREFIX = "Opossum_input_"
@@ -96,6 +101,7 @@ def run_scanner(src_path, dep_arguments, output_path, keep_raw_data=False,
     create_csv = False
     final_excel_dir = output_path
     success = True
+    temp_output_fiiles = []
     if not remove_src_data:
         success, final_excel_dir, result_log = init(output_path)
 
@@ -124,18 +130,30 @@ def run_scanner(src_path, dep_arguments, output_path, keep_raw_data=False,
                                                     -1, reuse_lint,
                                                     abs_path, "", False,
                                                     output_reuse)
-                copy_file(output_reuse, output_path)
+                success_file, copied_file = copy_file(output_reuse, output_path)
+                if success_file:
+                    temp_output_fiiles.append(copied_file)
 
             if run_src:
                 try:
-                    success, result = call_analysis_api(src_path, "Source Analysis",
-                                                        -1, source_analysis,
-                                                        abs_path,
-                                                        os.path.join(_output_dir, output_files["SRC"]),
-                                                        False, num_cores, True)
-                    if success:
-                        sheet_list["SRC_FL_Source"] = [scan_item.get_row_to_print() for scan_item in result[2]]
-                        create_report_file(0, result[2], result[3], 'all', True, _output_dir, output_files["SRC"], "")
+                    if fosslight_source_installed:
+                        src_output = os.path.join(_output_dir, output_files["SRC"])
+                        success, result = call_analysis_api(src_path, "Source Analysis",
+                                                            -1, source_analysis,
+                                                            abs_path,
+                                                            src_output,
+                                                            False, num_cores, True)
+                        if success:
+                            sheet_list["SRC_FL_Source"] = [scan_item.get_row_to_print() for scan_item in result[2]]
+                            create_report_file(0, result[2], result[3], 'all', True, _output_dir, output_files["SRC"], "")
+                    else:  # Run fosslight_source by using docker image
+                        src_output = os.path.join("output", output_files["SRC"])
+                        output_rel_path = os.path.relpath(abs_path, os.getcwd())
+                        command = f"docker run -it -v {_output_dir}:/app/output "\
+                                  f"fosslight -p {output_rel_path} -o {src_output}.xlsx"
+                        command_result = subprocess.run(command.split(' '), stdout=subprocess.PIPE, text=True)
+                        logger.info(f"Source Analysis Result:{command_result.stdout}")
+
                 except Exception as ex:
                     logger.warning(f"Failed to run source analysis: {ex}")
 
@@ -146,7 +164,9 @@ def run_scanner(src_path, dep_arguments, output_path, keep_raw_data=False,
                                                os.path.join(_output_dir, output_files["BIN"]),
                                                "", db_url)
                 if success:
-                    copy_file(os.path.join(_output_dir, output_files["BIN_TXT"]), output_path)
+                    success_file, copied_file = copy_file(os.path.join(_output_dir, output_files["BIN_TXT"]), output_path)
+                    if success_file:
+                        temp_output_fiiles.append(copied_file)
 
             if run_dep:
                 run_dependency(src_path, os.path.join(_output_dir, output_files["DEP"]), dep_arguments)
@@ -165,7 +185,8 @@ def run_scanner(src_path, dep_arguments, output_path, keep_raw_data=False,
         success, output_files = merge_excels(_output_dir, final_report, create_csv)
 
         if success and output_files:
-            result_log["Output File"] = output_files.split(",")
+            temp_output_fiiles.extend(output_files.split(","))
+            result_log["Output File"] = temp_output_fiiles
         else:
             logger.error(f"Fail to generate a result file. : {output_files}")
 
@@ -194,6 +215,7 @@ def download_source(link, out_dir):
         temp_src_dir = os.path.join(
             _output_dir, SRC_DIR_FROM_LINK_PREFIX + start_time)
 
+        link = link.strip()
         logger.info(f"Link to download: {link}")
         success, msg = cli_download_and_extract(
             link, temp_src_dir, _output_dir)
@@ -235,8 +257,11 @@ def init(output_path=""):
 
 def run_main(mode, src_path, dep_arguments, output_file_or_dir, file_format, url_to_analyze, db_url,
              hide_progressbar=False, keep_raw_data=False, num_cores=-1):
+    global _executed_path
+
     output_file = ""
-    output_path = _executed_path
+    default_oss_name = ""
+    _executed_path = os.getcwd()
     try:
         success, msg, output_path, output_file, output_extension = check_output_format(output_file_or_dir, file_format)
         if not success:
@@ -248,6 +273,8 @@ def run_main(mode, src_path, dep_arguments, output_file_or_dir, file_format, url
             run_dep = False
             run_reuse = False
             remove_downloaded_source = False
+            if output_path == "":
+                output_path = _executed_path
 
             if src_path == "" and url_to_analyze == "":
                 src_path, dep_arguments, url_to_analyze = get_input_mode()
